@@ -11,7 +11,6 @@ import urllib.parse as path_encoder
 
 HELLO_WORLD_MESSAGE = 'Hello world! PyOhio Demo - 3! CLEpy'
 
-#API_GW = "https://qe3b75sz3m.execute-api.us-east-2.amazonaws.com/api/"
 API_GW = "https://ck78dwtl1j.execute-api.cn-north-1.amazonaws.com.cn/api/"
 
 def get_message():
@@ -43,17 +42,22 @@ def create_training_job(local_data, source_code, weights, hyper_param):
 
     # upload data and code to s3
     # https://boto3.amazonaws.com/v1/documentation/api/latest/guide/s3-presigned-urls.html
+    """
     if local_data is not None:
-        # **********haiyan**********
         if local_data.startswith('s3://'):
             with open("s3_public_dataset.txt", 'w') as f:
                 f.write(local_data)
             __upload_one_file(job_id, FileType.Traindata.name, "s3_public_dataset.txt")
-            print(f"use s3 public dataset  {local_data}")
+            print(f"use s3 public datasets  {local_data}")
         else:
-        # **********haiyan**********
             __upload_one_folder(job_id, FileType.Traindata.name, local_data)
             print(f"uploaded {local_data}")
+    """
+    if local_data is not None:
+        __upload_one_folder(job_id, FileType.Traindata.name, local_data)
+        print(f"uploaded {local_data}")
+    else:
+        print("Please at s3_position input S3 public datasetes url")
 
     if source_code is not None:
         __upload_one_file(job_id, FileType.Code.name, source_code)
@@ -188,7 +192,28 @@ if __name__ == "__main__":
     #__list_files("test")
     #getFloderFiles("test")
     #print(files)
-    #make_tar("yolov5")
-    create_training_job("datasets_simple", "yolov5.tar", "yolov5s.pt", {"instance_type":"ml.m5.xlarge", "instance_count":"1", "use_public_datasets":"False", "framework_version":"1.8.1", "hyperparameters":{"imgsz":"64", "epochs":"10"}})
+
+    #make_tar("yolov5") 
+    #s3://code-devcloud/jobs/05ec9d2d-8862-49c1-9d1c-a39125e23fc2/Traindata/datasets_simple/
+    
+    create_training_job(None,
+                        "yolov5.tar",
+                        "yolov5s.pt",
+                        {"instance_type":"ml.m5.xlarge",
+                        "s3_position":"s3://code-devcloud/jobs/05ec9d2d-8862-49c1-9d1c-a39125e23fc2/Traindata/datasets_simple/",
+                        "instance_count":"1",
+                        "framework_version":"1.8.1",
+                        "hyperparameters":{"imgsz":"64", "epochs":"10"}})
+    
     #make_tar("train.py")
-    #create_training_job("mnist", "train.tar", None, {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"epochs":"2","backend":"gloo", "hidden_channels":"2", "dropout":"0.2","kernel_size":"5", "optimizer":"sgd"}})
+    #s3://code-devcloud/jobs/090e3c81-804a-4a34-abfb-33d67d77bfa8/Traindata/mnist/
+    """
+    create_training_job(None,
+                        "train.tar",
+                        None,
+                        {"instance_type":"ml.m5.xlarge",
+                        "s3_position":"s3://code-devcloud/jobs/090e3c81-804a-4a34-abfb-33d67d77bfa8/Traindata/mnist/",
+                        "instance_count":"1",
+                        "framework_version":"1.1.0",
+                        "hyperparameters":{"epochs":"4","backend":"gloo", "hidden_channels":"2", "dropout":"0.2","kernel_size":"5", "optimizer":"sgd"}})
+   """ 
